@@ -2,6 +2,7 @@
 #'
 #' @param .data \code{list}
 #' @param cond A logical lambda expression
+#' @param envir The environment to evaluate mapping function
 #' @name list.filter
 #' @export
 #' @examples
@@ -12,6 +13,6 @@
 #' list.filter(x,type=="B")
 #' list.filter(x,min(score$c1,score$c2) >= 8)
 #' }
-list.filter <- function(.data,cond) {
-  list.clean(.data[list.if.internal(.data,substitute(cond))])
+list.filter <- function(.data,cond,envir = parent.frame()) {
+  list.clean(.data[list.is.internal(.data,substitute(cond),envir)])
 }
