@@ -3,6 +3,7 @@
 #' @param .data \code{list}
 #' @param key A lambda expression for the group key
 #' @param ... Additional parameters passed to \code{unique}
+#' @param envir The environment to evaluate mapping function
 #' @name list.group
 #' @export
 #' @examples
@@ -13,8 +14,8 @@
 #' list.group(x,type)
 #' list.group(x,mean(unlist(score)))
 #' }
-list.group <- function(.data,key,...) {
-  keys <- list.map.internal(.data,substitute(key))
+list.group <- function(.data,key,...,envir = parent.frame()) {
+  keys <- list.map.internal(.data,substitute(key),envir = envir)
   unikeys <- unique(keys,...)
   names(unikeys) <- as.character(unikeys)
   lapply(unikeys,function(k) {
