@@ -3,8 +3,10 @@
 #'
 #' @param .data \code{list}
 #' @param expr A lambda expression
+#' @param envir The environment to evaluate mapping function
 #' @name list.iter
 #' @export
+#' @return \code{invisible(.data)}
 #' @examples
 #' \dontrun{
 #' x <- list(p1 = list(type="A",score=list(c1=10,c2=8)),
@@ -13,7 +15,7 @@
 #' list.iter(x,cat(paste(type,"\n")))
 #' list.iter(x,cat(str(.)))
 #' }
-list.iter <- function(.data,expr) {
-  list.map.internal(.data,substitute(expr))
-  invisible()
+list.iter <- function(.data,expr,envir = parent.frame()) {
+  list.map.internal(.data,substitute(expr),envir = envir)
+  invisible(.data)
 }
