@@ -2,6 +2,7 @@
 #'
 #' @param .data \code{list}
 #' @param expr A lambda expression
+#' @param envir The environment to evaluate mapping function
 #' @name list.map
 #' @export
 #' @examples
@@ -12,8 +13,8 @@
 #' list.map(x,type)
 #' list.map(x,min(score$c1,score$c2))
 #' }
-list.map <- function(.data,expr) {
-  list.map.internal(.data,substitute(expr))
+list.map <- function(.data,expr,envir=parent.frame()) {
+  list.map.internal(.data,substitute(expr),envir = envir)
 }
 
 #' Map each member of a list by an expression to a vector.
@@ -21,6 +22,7 @@ list.map <- function(.data,expr) {
 #' @param .data \code{list}
 #' @param expr The expression
 #' @param use.names Should the names of the results be preserved?
+#' @param envir The environment to evaluate mapping function
 #' @name list.mapv
 #' @export
 #' @examples
@@ -31,6 +33,7 @@ list.map <- function(.data,expr) {
 #' list.mapv(x,type)
 #' list.mapv(x,min(score$c1,score$c2))
 #' }
-list.mapv <- function(.data,expr,use.names=TRUE) {
-  unlist(list.map.internal(.data,substitute(expr)),use.names=use.names)
+list.mapv <- function(.data,expr,use.names=TRUE,envir=parent.frame()) {
+  unlist(list.map.internal(.data,substitute(expr),envir = envir),
+    use.names=use.names)
 }
