@@ -1,6 +1,6 @@
 #' Reverse a list
 #'
-#' @param x The list to be reversed
+#' @param .data \code{list}
 #' @name list.reverse
 #' @export
 #' @examples
@@ -8,6 +8,6 @@
 #' x <- list(a=1,b=2,c=3)
 #' list.reverse(x)
 #' }
-list.reverse <- function(x) {
-  x[rev(seq_along(x))]
+list.reverse <- function(.data) {
+  .data[rev(seq_along(.data))]
 }
