@@ -2,6 +2,7 @@
 #'
 #' @param .data \code{list}
 #' @param ... A group of implicit labmda expressions
+#' @param .envir The environment to evaluate mapping function
 #' @name list.select
 #' @export
 #' @examples
@@ -14,8 +15,8 @@
 #' list.select(x,type,score)
 #' list.select(x,type,score.range=range(unlist(score)))
 #' }
-list.select <- function(.data,...) {
+list.select <- function(.data,...,.envir = parent.frame()) {
   args <- set_argnames(dots(...))
   quote <- as.call(c(quote(list),args))
-  list.map.internal(.data,quote)
+  list.map.internal(.data,quote,envir = .envir)
 }
